@@ -1,7 +1,8 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "vs-dark-theme" "2.0"
+(define-package "vs-dark-theme" "20251111.322"
   "Visual Studio IDE dark theme."
   '((emacs "24.1"))
   :url "https://github.com/emacs-vs/vs-dark-theme"
-  :commit "b350d516e413632fc897af8de011db0f93044321"
-  :revdesc "b350d516e413")
+  :commit "3618c438b8eba8f89cba760b546c3d0f69c9d167"
+  :revdesc "3618c438b8eb"
+  :keywords '("faces"))
